@@ -1,5 +1,5 @@
 package App::week;
-our $VERSION = "1.0303";
+our $VERSION = "1.04";
 
 use v5.14;
 use warnings;
@@ -163,9 +163,10 @@ sub deal_option {
 
     # load --colormap option
     my %colormap = %DEFAULT_COLORMAP;
-    $app->COLORMAP(\%colormap);
-    $app->CM(Getopt::EX::Colormap->new(HASH => \%colormap)
-	     ->load_params(@{$app->colormap}));
+    $app->COLORMAP = \%colormap;
+    $app->CM = Getopt::EX::Colormap
+	->new(HASH => \%colormap)
+	->load_params(@{$app->colormap});
 
     # --colordump
     if ($app->colordump) {
@@ -343,7 +344,7 @@ B<week> [ -MI<module> ] [ option ] [ date ]
 
 =head1 VERSION
 
-Version 1.0303
+Version 1.04
 
 =head1 DESCRIPTION
 
